"""
Type annotations for cloudtrail-data service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/)

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_cloudtrail_data.client import CloudTrailDataServiceClient

    session = Session()
    client: CloudTrailDataServiceClient = session.client("cloudtrail-data")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import Any, Mapping

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import PutAuditEventsRequestRequestTypeDef, PutAuditEventsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("CloudTrailDataServiceClient",)

class Exceptions(BaseClientExceptions):
    ChannelInsufficientPermission: type[BotocoreClientError]
    ChannelNotFound: type[BotocoreClientError]
    ChannelUnsupportedSchema: type[BotocoreClientError]
    ClientError: type[BotocoreClientError]
    DuplicatedAuditEventId: type[BotocoreClientError]
    InvalidChannelARN: type[BotocoreClientError]
    UnsupportedOperationException: type[BotocoreClientError]

class CloudTrailDataServiceClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data.html#CloudTrailDataService.Client)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        CloudTrailDataServiceClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data.html#CloudTrailDataService.Client)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data/client/can_paginate.html)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data/client/generate_presigned_url.html)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/#generate_presigned_url)
        """

    def put_audit_events(
        self, **kwargs: Unpack[PutAuditEventsRequestRequestTypeDef]
    ) -> PutAuditEventsResponseTypeDef:
        """
        Ingests your application events into CloudTrail Lake.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudtrail-data/client/put_audit_events.html)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudtrail_data/client/#put_audit_events)
        """
