"""
Type annotations for elasticbeanstalk service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_elasticbeanstalk/type_defs/)

Usage::

    ```python
    from types_boto3_elasticbeanstalk.type_defs import AbortEnvironmentUpdateMessageRequestTypeDef

    data: AbortEnvironmentUpdateMessageRequestTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Sequence, Union

from .literals import (
    ActionHistoryStatusType,
    ActionStatusType,
    ActionTypeType,
    ApplicationVersionStatusType,
    ComputeTypeType,
    ConfigurationDeploymentStatusType,
    ConfigurationOptionValueTypeType,
    EnvironmentHealthAttributeType,
    EnvironmentHealthStatusType,
    EnvironmentHealthType,
    EnvironmentInfoTypeType,
    EnvironmentStatusType,
    EventSeverityType,
    FailureTypeType,
    InstancesHealthAttributeType,
    PlatformStatusType,
    SourceRepositoryType,
    SourceTypeType,
    ValidationSeverityType,
)

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "AbortEnvironmentUpdateMessageRequestTypeDef",
    "ApplicationDescriptionMessageTypeDef",
    "ApplicationDescriptionTypeDef",
    "ApplicationDescriptionsMessageTypeDef",
    "ApplicationMetricsTypeDef",
    "ApplicationResourceLifecycleConfigTypeDef",
    "ApplicationResourceLifecycleDescriptionMessageTypeDef",
    "ApplicationVersionDescriptionMessageTypeDef",
    "ApplicationVersionDescriptionTypeDef",
    "ApplicationVersionDescriptionsMessageTypeDef",
    "ApplicationVersionLifecycleConfigTypeDef",
    "ApplyEnvironmentManagedActionRequestRequestTypeDef",
    "ApplyEnvironmentManagedActionResultTypeDef",
    "AssociateEnvironmentOperationsRoleMessageRequestTypeDef",
    "AutoScalingGroupTypeDef",
    "BuildConfigurationTypeDef",
    "BuilderTypeDef",
    "CPUUtilizationTypeDef",
    "CheckDNSAvailabilityMessageRequestTypeDef",
    "CheckDNSAvailabilityResultMessageTypeDef",
    "ComposeEnvironmentsMessageRequestTypeDef",
    "ConfigurationOptionDescriptionTypeDef",
    "ConfigurationOptionSettingTypeDef",
    "ConfigurationOptionsDescriptionTypeDef",
    "ConfigurationSettingsDescriptionResponseTypeDef",
    "ConfigurationSettingsDescriptionTypeDef",
    "ConfigurationSettingsDescriptionsTypeDef",
    "ConfigurationSettingsValidationMessagesTypeDef",
    "CreateApplicationMessageRequestTypeDef",
    "CreateApplicationVersionMessageRequestTypeDef",
    "CreateConfigurationTemplateMessageRequestTypeDef",
    "CreateEnvironmentMessageRequestTypeDef",
    "CreatePlatformVersionRequestRequestTypeDef",
    "CreatePlatformVersionResultTypeDef",
    "CreateStorageLocationResultMessageTypeDef",
    "CustomAmiTypeDef",
    "DeleteApplicationMessageRequestTypeDef",
    "DeleteApplicationVersionMessageRequestTypeDef",
    "DeleteConfigurationTemplateMessageRequestTypeDef",
    "DeleteEnvironmentConfigurationMessageRequestTypeDef",
    "DeletePlatformVersionRequestRequestTypeDef",
    "DeletePlatformVersionResultTypeDef",
    "DeploymentTypeDef",
    "DescribeAccountAttributesResultTypeDef",
    "DescribeApplicationVersionsMessagePaginateTypeDef",
    "DescribeApplicationVersionsMessageRequestTypeDef",
    "DescribeApplicationsMessageRequestTypeDef",
    "DescribeConfigurationOptionsMessageRequestTypeDef",
    "DescribeConfigurationSettingsMessageRequestTypeDef",
    "DescribeEnvironmentHealthRequestRequestTypeDef",
    "DescribeEnvironmentHealthResultTypeDef",
    "DescribeEnvironmentManagedActionHistoryRequestPaginateTypeDef",
    "DescribeEnvironmentManagedActionHistoryRequestRequestTypeDef",
    "DescribeEnvironmentManagedActionHistoryResultTypeDef",
    "DescribeEnvironmentManagedActionsRequestRequestTypeDef",
    "DescribeEnvironmentManagedActionsResultTypeDef",
    "DescribeEnvironmentResourcesMessageRequestTypeDef",
    "DescribeEnvironmentsMessagePaginateTypeDef",
    "DescribeEnvironmentsMessageRequestTypeDef",
    "DescribeEnvironmentsMessageWaitTypeDef",
    "DescribeEventsMessagePaginateTypeDef",
    "DescribeEventsMessageRequestTypeDef",
    "DescribeInstancesHealthRequestRequestTypeDef",
    "DescribeInstancesHealthResultTypeDef",
    "DescribePlatformVersionRequestRequestTypeDef",
    "DescribePlatformVersionResultTypeDef",
    "DisassociateEnvironmentOperationsRoleMessageRequestTypeDef",
    "EmptyResponseMetadataTypeDef",
    "EnvironmentDescriptionResponseTypeDef",
    "EnvironmentDescriptionTypeDef",
    "EnvironmentDescriptionsMessageTypeDef",
    "EnvironmentInfoDescriptionTypeDef",
    "EnvironmentLinkTypeDef",
    "EnvironmentResourceDescriptionTypeDef",
    "EnvironmentResourceDescriptionsMessageTypeDef",
    "EnvironmentResourcesDescriptionTypeDef",
    "EnvironmentTierTypeDef",
    "EventDescriptionTypeDef",
    "EventDescriptionsMessageTypeDef",
    "InstanceHealthSummaryTypeDef",
    "InstanceTypeDef",
    "LatencyTypeDef",
    "LaunchConfigurationTypeDef",
    "LaunchTemplateTypeDef",
    "ListAvailableSolutionStacksResultMessageTypeDef",
    "ListPlatformBranchesRequestRequestTypeDef",
    "ListPlatformBranchesResultTypeDef",
    "ListPlatformVersionsRequestPaginateTypeDef",
    "ListPlatformVersionsRequestRequestTypeDef",
    "ListPlatformVersionsResultTypeDef",
    "ListTagsForResourceMessageRequestTypeDef",
    "ListenerTypeDef",
    "LoadBalancerDescriptionTypeDef",
    "LoadBalancerTypeDef",
    "ManagedActionHistoryItemTypeDef",
    "ManagedActionTypeDef",
    "MaxAgeRuleTypeDef",
    "MaxCountRuleTypeDef",
    "OptionRestrictionRegexTypeDef",
    "OptionSpecificationTypeDef",
    "PaginatorConfigTypeDef",
    "PlatformBranchSummaryTypeDef",
    "PlatformDescriptionTypeDef",
    "PlatformFilterTypeDef",
    "PlatformFrameworkTypeDef",
    "PlatformProgrammingLanguageTypeDef",
    "PlatformSummaryTypeDef",
    "QueueTypeDef",
    "RebuildEnvironmentMessageRequestTypeDef",
    "RequestEnvironmentInfoMessageRequestTypeDef",
    "ResourceQuotaTypeDef",
    "ResourceQuotasTypeDef",
    "ResourceTagsDescriptionMessageTypeDef",
    "ResponseMetadataTypeDef",
    "RestartAppServerMessageRequestTypeDef",
    "RetrieveEnvironmentInfoMessageRequestTypeDef",
    "RetrieveEnvironmentInfoResultMessageTypeDef",
    "S3LocationTypeDef",
    "SearchFilterTypeDef",
    "SingleInstanceHealthTypeDef",
    "SolutionStackDescriptionTypeDef",
    "SourceBuildInformationTypeDef",
    "SourceConfigurationTypeDef",
    "StatusCodesTypeDef",
    "SwapEnvironmentCNAMEsMessageRequestTypeDef",
    "SystemStatusTypeDef",
    "TagTypeDef",
    "TerminateEnvironmentMessageRequestTypeDef",
    "TimestampTypeDef",
    "TriggerTypeDef",
    "UpdateApplicationMessageRequestTypeDef",
    "UpdateApplicationResourceLifecycleMessageRequestTypeDef",
    "UpdateApplicationVersionMessageRequestTypeDef",
    "UpdateConfigurationTemplateMessageRequestTypeDef",
    "UpdateEnvironmentMessageRequestTypeDef",
    "UpdateTagsForResourceMessageRequestTypeDef",
    "ValidateConfigurationSettingsMessageRequestTypeDef",
    "ValidationMessageTypeDef",
    "WaiterConfigTypeDef",
)


class AbortEnvironmentUpdateMessageRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class LatencyTypeDef(TypedDict):
    P999: NotRequired[float]
    P99: NotRequired[float]
    P95: NotRequired[float]
    P90: NotRequired[float]
    P85: NotRequired[float]
    P75: NotRequired[float]
    P50: NotRequired[float]
    P10: NotRequired[float]


class StatusCodesTypeDef(TypedDict):
    Status2xx: NotRequired[int]
    Status3xx: NotRequired[int]
    Status4xx: NotRequired[int]
    Status5xx: NotRequired[int]


class S3LocationTypeDef(TypedDict):
    S3Bucket: NotRequired[str]
    S3Key: NotRequired[str]


class SourceBuildInformationTypeDef(TypedDict):
    SourceType: SourceTypeType
    SourceRepository: SourceRepositoryType
    SourceLocation: str


class MaxAgeRuleTypeDef(TypedDict):
    Enabled: bool
    MaxAgeInDays: NotRequired[int]
    DeleteSourceFromS3: NotRequired[bool]


class MaxCountRuleTypeDef(TypedDict):
    Enabled: bool
    MaxCount: NotRequired[int]
    DeleteSourceFromS3: NotRequired[bool]


class ApplyEnvironmentManagedActionRequestRequestTypeDef(TypedDict):
    ActionId: str
    EnvironmentName: NotRequired[str]
    EnvironmentId: NotRequired[str]


class AssociateEnvironmentOperationsRoleMessageRequestTypeDef(TypedDict):
    EnvironmentName: str
    OperationsRole: str


class AutoScalingGroupTypeDef(TypedDict):
    Name: NotRequired[str]


class BuildConfigurationTypeDef(TypedDict):
    CodeBuildServiceRole: str
    Image: str
    ArtifactName: NotRequired[str]
    ComputeType: NotRequired[ComputeTypeType]
    TimeoutInMinutes: NotRequired[int]


class BuilderTypeDef(TypedDict):
    ARN: NotRequired[str]


class CPUUtilizationTypeDef(TypedDict):
    User: NotRequired[float]
    Nice: NotRequired[float]
    System: NotRequired[float]
    Idle: NotRequired[float]
    IOWait: NotRequired[float]
    IRQ: NotRequired[float]
    SoftIRQ: NotRequired[float]
    Privileged: NotRequired[float]


class CheckDNSAvailabilityMessageRequestTypeDef(TypedDict):
    CNAMEPrefix: str


class ComposeEnvironmentsMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    GroupName: NotRequired[str]
    VersionLabels: NotRequired[Sequence[str]]


OptionRestrictionRegexTypeDef = TypedDict(
    "OptionRestrictionRegexTypeDef",
    {
        "Pattern": NotRequired[str],
        "Label": NotRequired[str],
    },
)


class ConfigurationOptionSettingTypeDef(TypedDict):
    ResourceName: NotRequired[str]
    Namespace: NotRequired[str]
    OptionName: NotRequired[str]
    Value: NotRequired[str]


class ValidationMessageTypeDef(TypedDict):
    Message: NotRequired[str]
    Severity: NotRequired[ValidationSeverityType]
    Namespace: NotRequired[str]
    OptionName: NotRequired[str]


class TagTypeDef(TypedDict):
    Key: NotRequired[str]
    Value: NotRequired[str]


class SourceConfigurationTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    TemplateName: NotRequired[str]


EnvironmentTierTypeDef = TypedDict(
    "EnvironmentTierTypeDef",
    {
        "Name": NotRequired[str],
        "Type": NotRequired[str],
        "Version": NotRequired[str],
    },
)


class OptionSpecificationTypeDef(TypedDict):
    ResourceName: NotRequired[str]
    Namespace: NotRequired[str]
    OptionName: NotRequired[str]


class PlatformSummaryTypeDef(TypedDict):
    PlatformArn: NotRequired[str]
    PlatformOwner: NotRequired[str]
    PlatformStatus: NotRequired[PlatformStatusType]
    PlatformCategory: NotRequired[str]
    OperatingSystemName: NotRequired[str]
    OperatingSystemVersion: NotRequired[str]
    SupportedTierList: NotRequired[list[str]]
    SupportedAddonList: NotRequired[list[str]]
    PlatformLifecycleState: NotRequired[str]
    PlatformVersion: NotRequired[str]
    PlatformBranchName: NotRequired[str]
    PlatformBranchLifecycleState: NotRequired[str]


class CustomAmiTypeDef(TypedDict):
    VirtualizationType: NotRequired[str]
    ImageId: NotRequired[str]


class DeleteApplicationMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    TerminateEnvByForce: NotRequired[bool]


class DeleteApplicationVersionMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    VersionLabel: str
    DeleteSourceBundle: NotRequired[bool]


class DeleteConfigurationTemplateMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    TemplateName: str


class DeleteEnvironmentConfigurationMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    EnvironmentName: str


class DeletePlatformVersionRequestRequestTypeDef(TypedDict):
    PlatformArn: NotRequired[str]


class DeploymentTypeDef(TypedDict):
    VersionLabel: NotRequired[str]
    DeploymentId: NotRequired[int]
    Status: NotRequired[str]
    DeploymentTime: NotRequired[datetime]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class DescribeApplicationVersionsMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabels: NotRequired[Sequence[str]]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]


class DescribeApplicationsMessageRequestTypeDef(TypedDict):
    ApplicationNames: NotRequired[Sequence[str]]


class DescribeConfigurationSettingsMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    TemplateName: NotRequired[str]
    EnvironmentName: NotRequired[str]


class DescribeEnvironmentHealthRequestRequestTypeDef(TypedDict):
    EnvironmentName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    AttributeNames: NotRequired[Sequence[EnvironmentHealthAttributeType]]


InstanceHealthSummaryTypeDef = TypedDict(
    "InstanceHealthSummaryTypeDef",
    {
        "NoData": NotRequired[int],
        "Unknown": NotRequired[int],
        "Pending": NotRequired[int],
        "Ok": NotRequired[int],
        "Info": NotRequired[int],
        "Warning": NotRequired[int],
        "Degraded": NotRequired[int],
        "Severe": NotRequired[int],
    },
)


class DescribeEnvironmentManagedActionHistoryRequestRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    NextToken: NotRequired[str]
    MaxItems: NotRequired[int]


class ManagedActionHistoryItemTypeDef(TypedDict):
    ActionId: NotRequired[str]
    ActionType: NotRequired[ActionTypeType]
    ActionDescription: NotRequired[str]
    FailureType: NotRequired[FailureTypeType]
    Status: NotRequired[ActionHistoryStatusType]
    FailureDescription: NotRequired[str]
    ExecutedTime: NotRequired[datetime]
    FinishedTime: NotRequired[datetime]


class DescribeEnvironmentManagedActionsRequestRequestTypeDef(TypedDict):
    EnvironmentName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    Status: NotRequired[ActionStatusType]


class ManagedActionTypeDef(TypedDict):
    ActionId: NotRequired[str]
    ActionDescription: NotRequired[str]
    ActionType: NotRequired[ActionTypeType]
    Status: NotRequired[ActionStatusType]
    WindowStartTime: NotRequired[datetime]


class DescribeEnvironmentResourcesMessageRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


TimestampTypeDef = Union[datetime, str]


class WaiterConfigTypeDef(TypedDict):
    Delay: NotRequired[int]
    MaxAttempts: NotRequired[int]


class DescribeInstancesHealthRequestRequestTypeDef(TypedDict):
    EnvironmentName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    AttributeNames: NotRequired[Sequence[InstancesHealthAttributeType]]
    NextToken: NotRequired[str]


class DescribePlatformVersionRequestRequestTypeDef(TypedDict):
    PlatformArn: NotRequired[str]


class DisassociateEnvironmentOperationsRoleMessageRequestTypeDef(TypedDict):
    EnvironmentName: str


class EnvironmentLinkTypeDef(TypedDict):
    LinkName: NotRequired[str]
    EnvironmentName: NotRequired[str]


class EnvironmentInfoDescriptionTypeDef(TypedDict):
    InfoType: NotRequired[EnvironmentInfoTypeType]
    Ec2InstanceId: NotRequired[str]
    SampleTimestamp: NotRequired[datetime]
    Message: NotRequired[str]


class InstanceTypeDef(TypedDict):
    Id: NotRequired[str]


class LaunchConfigurationTypeDef(TypedDict):
    Name: NotRequired[str]


class LaunchTemplateTypeDef(TypedDict):
    Id: NotRequired[str]


class LoadBalancerTypeDef(TypedDict):
    Name: NotRequired[str]


class QueueTypeDef(TypedDict):
    Name: NotRequired[str]
    URL: NotRequired[str]


class TriggerTypeDef(TypedDict):
    Name: NotRequired[str]


class EventDescriptionTypeDef(TypedDict):
    EventDate: NotRequired[datetime]
    Message: NotRequired[str]
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    TemplateName: NotRequired[str]
    EnvironmentName: NotRequired[str]
    PlatformArn: NotRequired[str]
    RequestId: NotRequired[str]
    Severity: NotRequired[EventSeverityType]


class SolutionStackDescriptionTypeDef(TypedDict):
    SolutionStackName: NotRequired[str]
    PermittedFileTypes: NotRequired[list[str]]


class SearchFilterTypeDef(TypedDict):
    Attribute: NotRequired[str]
    Operator: NotRequired[str]
    Values: NotRequired[Sequence[str]]


class PlatformBranchSummaryTypeDef(TypedDict):
    PlatformName: NotRequired[str]
    BranchName: NotRequired[str]
    LifecycleState: NotRequired[str]
    BranchOrder: NotRequired[int]
    SupportedTierList: NotRequired[list[str]]


PlatformFilterTypeDef = TypedDict(
    "PlatformFilterTypeDef",
    {
        "Type": NotRequired[str],
        "Operator": NotRequired[str],
        "Values": NotRequired[Sequence[str]],
    },
)


class ListTagsForResourceMessageRequestTypeDef(TypedDict):
    ResourceArn: str


ListenerTypeDef = TypedDict(
    "ListenerTypeDef",
    {
        "Protocol": NotRequired[str],
        "Port": NotRequired[int],
    },
)


class PlatformFrameworkTypeDef(TypedDict):
    Name: NotRequired[str]
    Version: NotRequired[str]


class PlatformProgrammingLanguageTypeDef(TypedDict):
    Name: NotRequired[str]
    Version: NotRequired[str]


class RebuildEnvironmentMessageRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


class RequestEnvironmentInfoMessageRequestTypeDef(TypedDict):
    InfoType: EnvironmentInfoTypeType
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


class ResourceQuotaTypeDef(TypedDict):
    Maximum: NotRequired[int]


class RestartAppServerMessageRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


class RetrieveEnvironmentInfoMessageRequestTypeDef(TypedDict):
    InfoType: EnvironmentInfoTypeType
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]


class SwapEnvironmentCNAMEsMessageRequestTypeDef(TypedDict):
    SourceEnvironmentId: NotRequired[str]
    SourceEnvironmentName: NotRequired[str]
    DestinationEnvironmentId: NotRequired[str]
    DestinationEnvironmentName: NotRequired[str]


class TerminateEnvironmentMessageRequestTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    TerminateResources: NotRequired[bool]
    ForceTerminate: NotRequired[bool]


class UpdateApplicationMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    Description: NotRequired[str]


class UpdateApplicationVersionMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    VersionLabel: str
    Description: NotRequired[str]


class ApplyEnvironmentManagedActionResultTypeDef(TypedDict):
    ActionId: str
    ActionDescription: str
    ActionType: ActionTypeType
    Status: str
    ResponseMetadata: ResponseMetadataTypeDef


class CheckDNSAvailabilityResultMessageTypeDef(TypedDict):
    Available: bool
    FullyQualifiedCNAME: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateStorageLocationResultMessageTypeDef(TypedDict):
    S3Bucket: str
    ResponseMetadata: ResponseMetadataTypeDef


class EmptyResponseMetadataTypeDef(TypedDict):
    ResponseMetadata: ResponseMetadataTypeDef


class ApplicationMetricsTypeDef(TypedDict):
    Duration: NotRequired[int]
    RequestCount: NotRequired[int]
    StatusCodes: NotRequired[StatusCodesTypeDef]
    Latency: NotRequired[LatencyTypeDef]


class ApplicationVersionDescriptionTypeDef(TypedDict):
    ApplicationVersionArn: NotRequired[str]
    ApplicationName: NotRequired[str]
    Description: NotRequired[str]
    VersionLabel: NotRequired[str]
    SourceBuildInformation: NotRequired[SourceBuildInformationTypeDef]
    BuildArn: NotRequired[str]
    SourceBundle: NotRequired[S3LocationTypeDef]
    DateCreated: NotRequired[datetime]
    DateUpdated: NotRequired[datetime]
    Status: NotRequired[ApplicationVersionStatusType]


class ApplicationVersionLifecycleConfigTypeDef(TypedDict):
    MaxCountRule: NotRequired[MaxCountRuleTypeDef]
    MaxAgeRule: NotRequired[MaxAgeRuleTypeDef]


class SystemStatusTypeDef(TypedDict):
    CPUUtilization: NotRequired[CPUUtilizationTypeDef]
    LoadAverage: NotRequired[list[float]]


class ConfigurationOptionDescriptionTypeDef(TypedDict):
    Namespace: NotRequired[str]
    Name: NotRequired[str]
    DefaultValue: NotRequired[str]
    ChangeSeverity: NotRequired[str]
    UserDefined: NotRequired[bool]
    ValueType: NotRequired[ConfigurationOptionValueTypeType]
    ValueOptions: NotRequired[list[str]]
    MinValue: NotRequired[int]
    MaxValue: NotRequired[int]
    MaxLength: NotRequired[int]
    Regex: NotRequired[OptionRestrictionRegexTypeDef]


class ConfigurationSettingsDescriptionResponseTypeDef(TypedDict):
    SolutionStackName: str
    PlatformArn: str
    ApplicationName: str
    TemplateName: str
    Description: str
    EnvironmentName: str
    DeploymentStatus: ConfigurationDeploymentStatusType
    DateCreated: datetime
    DateUpdated: datetime
    OptionSettings: list[ConfigurationOptionSettingTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class ConfigurationSettingsDescriptionTypeDef(TypedDict):
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    ApplicationName: NotRequired[str]
    TemplateName: NotRequired[str]
    Description: NotRequired[str]
    EnvironmentName: NotRequired[str]
    DeploymentStatus: NotRequired[ConfigurationDeploymentStatusType]
    DateCreated: NotRequired[datetime]
    DateUpdated: NotRequired[datetime]
    OptionSettings: NotRequired[list[ConfigurationOptionSettingTypeDef]]


class ValidateConfigurationSettingsMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    OptionSettings: Sequence[ConfigurationOptionSettingTypeDef]
    TemplateName: NotRequired[str]
    EnvironmentName: NotRequired[str]


class ConfigurationSettingsValidationMessagesTypeDef(TypedDict):
    Messages: list[ValidationMessageTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class CreateApplicationVersionMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    VersionLabel: str
    Description: NotRequired[str]
    SourceBuildInformation: NotRequired[SourceBuildInformationTypeDef]
    SourceBundle: NotRequired[S3LocationTypeDef]
    BuildConfiguration: NotRequired[BuildConfigurationTypeDef]
    AutoCreateApplication: NotRequired[bool]
    Process: NotRequired[bool]
    Tags: NotRequired[Sequence[TagTypeDef]]


class CreatePlatformVersionRequestRequestTypeDef(TypedDict):
    PlatformName: str
    PlatformVersion: str
    PlatformDefinitionBundle: S3LocationTypeDef
    EnvironmentName: NotRequired[str]
    OptionSettings: NotRequired[Sequence[ConfigurationOptionSettingTypeDef]]
    Tags: NotRequired[Sequence[TagTypeDef]]


class ResourceTagsDescriptionMessageTypeDef(TypedDict):
    ResourceArn: str
    ResourceTags: list[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateTagsForResourceMessageRequestTypeDef(TypedDict):
    ResourceArn: str
    TagsToAdd: NotRequired[Sequence[TagTypeDef]]
    TagsToRemove: NotRequired[Sequence[str]]


class CreateConfigurationTemplateMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    TemplateName: str
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    SourceConfiguration: NotRequired[SourceConfigurationTypeDef]
    EnvironmentId: NotRequired[str]
    Description: NotRequired[str]
    OptionSettings: NotRequired[Sequence[ConfigurationOptionSettingTypeDef]]
    Tags: NotRequired[Sequence[TagTypeDef]]


class CreateEnvironmentMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    EnvironmentName: NotRequired[str]
    GroupName: NotRequired[str]
    Description: NotRequired[str]
    CNAMEPrefix: NotRequired[str]
    Tier: NotRequired[EnvironmentTierTypeDef]
    Tags: NotRequired[Sequence[TagTypeDef]]
    VersionLabel: NotRequired[str]
    TemplateName: NotRequired[str]
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    OptionSettings: NotRequired[Sequence[ConfigurationOptionSettingTypeDef]]
    OptionsToRemove: NotRequired[Sequence[OptionSpecificationTypeDef]]
    OperationsRole: NotRequired[str]


class DescribeConfigurationOptionsMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    TemplateName: NotRequired[str]
    EnvironmentName: NotRequired[str]
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    Options: NotRequired[Sequence[OptionSpecificationTypeDef]]


class UpdateConfigurationTemplateMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    TemplateName: str
    Description: NotRequired[str]
    OptionSettings: NotRequired[Sequence[ConfigurationOptionSettingTypeDef]]
    OptionsToRemove: NotRequired[Sequence[OptionSpecificationTypeDef]]


class UpdateEnvironmentMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    GroupName: NotRequired[str]
    Description: NotRequired[str]
    Tier: NotRequired[EnvironmentTierTypeDef]
    VersionLabel: NotRequired[str]
    TemplateName: NotRequired[str]
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    OptionSettings: NotRequired[Sequence[ConfigurationOptionSettingTypeDef]]
    OptionsToRemove: NotRequired[Sequence[OptionSpecificationTypeDef]]


class CreatePlatformVersionResultTypeDef(TypedDict):
    PlatformSummary: PlatformSummaryTypeDef
    Builder: BuilderTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DeletePlatformVersionResultTypeDef(TypedDict):
    PlatformSummary: PlatformSummaryTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListPlatformVersionsResultTypeDef(TypedDict):
    PlatformSummaryList: list[PlatformSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class DescribeApplicationVersionsMessagePaginateTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabels: NotRequired[Sequence[str]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeEnvironmentManagedActionHistoryRequestPaginateTypeDef(TypedDict):
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeEnvironmentManagedActionHistoryResultTypeDef(TypedDict):
    ManagedActionHistoryItems: list[ManagedActionHistoryItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class DescribeEnvironmentManagedActionsResultTypeDef(TypedDict):
    ManagedActions: list[ManagedActionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeEnvironmentsMessagePaginateTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    EnvironmentIds: NotRequired[Sequence[str]]
    EnvironmentNames: NotRequired[Sequence[str]]
    IncludeDeleted: NotRequired[bool]
    IncludedDeletedBackTo: NotRequired[TimestampTypeDef]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeEnvironmentsMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    EnvironmentIds: NotRequired[Sequence[str]]
    EnvironmentNames: NotRequired[Sequence[str]]
    IncludeDeleted: NotRequired[bool]
    IncludedDeletedBackTo: NotRequired[TimestampTypeDef]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]


class DescribeEventsMessagePaginateTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    TemplateName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    PlatformArn: NotRequired[str]
    RequestId: NotRequired[str]
    Severity: NotRequired[EventSeverityType]
    StartTime: NotRequired[TimestampTypeDef]
    EndTime: NotRequired[TimestampTypeDef]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class DescribeEventsMessageRequestTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    TemplateName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    EnvironmentName: NotRequired[str]
    PlatformArn: NotRequired[str]
    RequestId: NotRequired[str]
    Severity: NotRequired[EventSeverityType]
    StartTime: NotRequired[TimestampTypeDef]
    EndTime: NotRequired[TimestampTypeDef]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]


class DescribeEnvironmentsMessageWaitTypeDef(TypedDict):
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    EnvironmentIds: NotRequired[Sequence[str]]
    EnvironmentNames: NotRequired[Sequence[str]]
    IncludeDeleted: NotRequired[bool]
    IncludedDeletedBackTo: NotRequired[TimestampTypeDef]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]
    WaiterConfig: NotRequired[WaiterConfigTypeDef]


class RetrieveEnvironmentInfoResultMessageTypeDef(TypedDict):
    EnvironmentInfo: list[EnvironmentInfoDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class EnvironmentResourceDescriptionTypeDef(TypedDict):
    EnvironmentName: NotRequired[str]
    AutoScalingGroups: NotRequired[list[AutoScalingGroupTypeDef]]
    Instances: NotRequired[list[InstanceTypeDef]]
    LaunchConfigurations: NotRequired[list[LaunchConfigurationTypeDef]]
    LaunchTemplates: NotRequired[list[LaunchTemplateTypeDef]]
    LoadBalancers: NotRequired[list[LoadBalancerTypeDef]]
    Triggers: NotRequired[list[TriggerTypeDef]]
    Queues: NotRequired[list[QueueTypeDef]]


class EventDescriptionsMessageTypeDef(TypedDict):
    Events: list[EventDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListAvailableSolutionStacksResultMessageTypeDef(TypedDict):
    SolutionStacks: list[str]
    SolutionStackDetails: list[SolutionStackDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class ListPlatformBranchesRequestRequestTypeDef(TypedDict):
    Filters: NotRequired[Sequence[SearchFilterTypeDef]]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]


class ListPlatformBranchesResultTypeDef(TypedDict):
    PlatformBranchSummaryList: list[PlatformBranchSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListPlatformVersionsRequestPaginateTypeDef(TypedDict):
    Filters: NotRequired[Sequence[PlatformFilterTypeDef]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListPlatformVersionsRequestRequestTypeDef(TypedDict):
    Filters: NotRequired[Sequence[PlatformFilterTypeDef]]
    MaxRecords: NotRequired[int]
    NextToken: NotRequired[str]


class LoadBalancerDescriptionTypeDef(TypedDict):
    LoadBalancerName: NotRequired[str]
    Domain: NotRequired[str]
    Listeners: NotRequired[list[ListenerTypeDef]]


class PlatformDescriptionTypeDef(TypedDict):
    PlatformArn: NotRequired[str]
    PlatformOwner: NotRequired[str]
    PlatformName: NotRequired[str]
    PlatformVersion: NotRequired[str]
    SolutionStackName: NotRequired[str]
    PlatformStatus: NotRequired[PlatformStatusType]
    DateCreated: NotRequired[datetime]
    DateUpdated: NotRequired[datetime]
    PlatformCategory: NotRequired[str]
    Description: NotRequired[str]
    Maintainer: NotRequired[str]
    OperatingSystemName: NotRequired[str]
    OperatingSystemVersion: NotRequired[str]
    ProgrammingLanguages: NotRequired[list[PlatformProgrammingLanguageTypeDef]]
    Frameworks: NotRequired[list[PlatformFrameworkTypeDef]]
    CustomAmiList: NotRequired[list[CustomAmiTypeDef]]
    SupportedTierList: NotRequired[list[str]]
    SupportedAddonList: NotRequired[list[str]]
    PlatformLifecycleState: NotRequired[str]
    PlatformBranchName: NotRequired[str]
    PlatformBranchLifecycleState: NotRequired[str]


class ResourceQuotasTypeDef(TypedDict):
    ApplicationQuota: NotRequired[ResourceQuotaTypeDef]
    ApplicationVersionQuota: NotRequired[ResourceQuotaTypeDef]
    EnvironmentQuota: NotRequired[ResourceQuotaTypeDef]
    ConfigurationTemplateQuota: NotRequired[ResourceQuotaTypeDef]
    CustomPlatformQuota: NotRequired[ResourceQuotaTypeDef]


class DescribeEnvironmentHealthResultTypeDef(TypedDict):
    EnvironmentName: str
    HealthStatus: str
    Status: EnvironmentHealthType
    Color: str
    Causes: list[str]
    ApplicationMetrics: ApplicationMetricsTypeDef
    InstancesHealth: InstanceHealthSummaryTypeDef
    RefreshedAt: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class ApplicationVersionDescriptionMessageTypeDef(TypedDict):
    ApplicationVersion: ApplicationVersionDescriptionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ApplicationVersionDescriptionsMessageTypeDef(TypedDict):
    ApplicationVersions: list[ApplicationVersionDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ApplicationResourceLifecycleConfigTypeDef(TypedDict):
    ServiceRole: NotRequired[str]
    VersionLifecycleConfig: NotRequired[ApplicationVersionLifecycleConfigTypeDef]


class SingleInstanceHealthTypeDef(TypedDict):
    InstanceId: NotRequired[str]
    HealthStatus: NotRequired[str]
    Color: NotRequired[str]
    Causes: NotRequired[list[str]]
    LaunchedAt: NotRequired[datetime]
    ApplicationMetrics: NotRequired[ApplicationMetricsTypeDef]
    System: NotRequired[SystemStatusTypeDef]
    Deployment: NotRequired[DeploymentTypeDef]
    AvailabilityZone: NotRequired[str]
    InstanceType: NotRequired[str]


class ConfigurationOptionsDescriptionTypeDef(TypedDict):
    SolutionStackName: str
    PlatformArn: str
    Options: list[ConfigurationOptionDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class ConfigurationSettingsDescriptionsTypeDef(TypedDict):
    ConfigurationSettings: list[ConfigurationSettingsDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class EnvironmentResourceDescriptionsMessageTypeDef(TypedDict):
    EnvironmentResources: EnvironmentResourceDescriptionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class EnvironmentResourcesDescriptionTypeDef(TypedDict):
    LoadBalancer: NotRequired[LoadBalancerDescriptionTypeDef]


class DescribePlatformVersionResultTypeDef(TypedDict):
    PlatformDescription: PlatformDescriptionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeAccountAttributesResultTypeDef(TypedDict):
    ResourceQuotas: ResourceQuotasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ApplicationDescriptionTypeDef(TypedDict):
    ApplicationArn: NotRequired[str]
    ApplicationName: NotRequired[str]
    Description: NotRequired[str]
    DateCreated: NotRequired[datetime]
    DateUpdated: NotRequired[datetime]
    Versions: NotRequired[list[str]]
    ConfigurationTemplates: NotRequired[list[str]]
    ResourceLifecycleConfig: NotRequired[ApplicationResourceLifecycleConfigTypeDef]


class ApplicationResourceLifecycleDescriptionMessageTypeDef(TypedDict):
    ApplicationName: str
    ResourceLifecycleConfig: ApplicationResourceLifecycleConfigTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class CreateApplicationMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    Description: NotRequired[str]
    ResourceLifecycleConfig: NotRequired[ApplicationResourceLifecycleConfigTypeDef]
    Tags: NotRequired[Sequence[TagTypeDef]]


class UpdateApplicationResourceLifecycleMessageRequestTypeDef(TypedDict):
    ApplicationName: str
    ResourceLifecycleConfig: ApplicationResourceLifecycleConfigTypeDef


class DescribeInstancesHealthResultTypeDef(TypedDict):
    InstanceHealthList: list[SingleInstanceHealthTypeDef]
    RefreshedAt: datetime
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class EnvironmentDescriptionResponseTypeDef(TypedDict):
    EnvironmentName: str
    EnvironmentId: str
    ApplicationName: str
    VersionLabel: str
    SolutionStackName: str
    PlatformArn: str
    TemplateName: str
    Description: str
    EndpointURL: str
    CNAME: str
    DateCreated: datetime
    DateUpdated: datetime
    Status: EnvironmentStatusType
    AbortableOperationInProgress: bool
    Health: EnvironmentHealthType
    HealthStatus: EnvironmentHealthStatusType
    Resources: EnvironmentResourcesDescriptionTypeDef
    Tier: EnvironmentTierTypeDef
    EnvironmentLinks: list[EnvironmentLinkTypeDef]
    EnvironmentArn: str
    OperationsRole: str
    ResponseMetadata: ResponseMetadataTypeDef


class EnvironmentDescriptionTypeDef(TypedDict):
    EnvironmentName: NotRequired[str]
    EnvironmentId: NotRequired[str]
    ApplicationName: NotRequired[str]
    VersionLabel: NotRequired[str]
    SolutionStackName: NotRequired[str]
    PlatformArn: NotRequired[str]
    TemplateName: NotRequired[str]
    Description: NotRequired[str]
    EndpointURL: NotRequired[str]
    CNAME: NotRequired[str]
    DateCreated: NotRequired[datetime]
    DateUpdated: NotRequired[datetime]
    Status: NotRequired[EnvironmentStatusType]
    AbortableOperationInProgress: NotRequired[bool]
    Health: NotRequired[EnvironmentHealthType]
    HealthStatus: NotRequired[EnvironmentHealthStatusType]
    Resources: NotRequired[EnvironmentResourcesDescriptionTypeDef]
    Tier: NotRequired[EnvironmentTierTypeDef]
    EnvironmentLinks: NotRequired[list[EnvironmentLinkTypeDef]]
    EnvironmentArn: NotRequired[str]
    OperationsRole: NotRequired[str]


class ApplicationDescriptionMessageTypeDef(TypedDict):
    Application: ApplicationDescriptionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ApplicationDescriptionsMessageTypeDef(TypedDict):
    Applications: list[ApplicationDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class EnvironmentDescriptionsMessageTypeDef(TypedDict):
    Environments: list[EnvironmentDescriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]
