"""
Type annotations for macie2 service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_macie2/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_macie2.client import Macie2Client
    from types_boto3_macie2.waiter import (
        FindingRevealedWaiter,
    )

    session = Session()
    client: Macie2Client = session.client("macie2")

    finding_revealed_waiter: FindingRevealedWaiter = client.get_waiter("finding_revealed")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import GetSensitiveDataOccurrencesRequestWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("FindingRevealedWaiter",)


class FindingRevealedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/macie2/waiter/FindingRevealed.html#Macie2.Waiter.FindingRevealed)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_macie2/waiters/#findingrevealedwaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[GetSensitiveDataOccurrencesRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/macie2/waiter/FindingRevealed.html#Macie2.Waiter.FindingRevealed.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_macie2/waiters/#findingrevealedwaiter)
        """
