"""
Type annotations for wellarchitected service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_wellarchitected/type_defs/)

Usage::

    ```python
    from types_boto3_wellarchitected.type_defs import AccountJiraConfigurationInputTypeDef

    data: AccountJiraConfigurationInputTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Mapping, Sequence, Union

from .literals import (
    AccountJiraIssueManagementStatusType,
    AdditionalResourceTypeType,
    AnswerReasonType,
    CheckFailureReasonType,
    CheckStatusType,
    ChoiceReasonType,
    ChoiceStatusType,
    DefinitionTypeType,
    DifferenceStatusType,
    DiscoveryIntegrationStatusType,
    ImportLensStatusType,
    IntegrationStatusType,
    IssueManagementTypeType,
    LensStatusType,
    LensStatusTypeType,
    LensTypeType,
    NotificationTypeType,
    OrganizationSharingStatusType,
    PermissionTypeType,
    ProfileNotificationTypeType,
    ProfileOwnerTypeType,
    QuestionPriorityType,
    QuestionType,
    QuestionTypeType,
    ReportFormatType,
    ReviewTemplateAnswerStatusType,
    ReviewTemplateUpdateStatusType,
    RiskType,
    ShareInvitationActionType,
    ShareResourceTypeType,
    ShareStatusType,
    TrustedAdvisorIntegrationStatusType,
    WorkloadEnvironmentType,
    WorkloadImprovementStatusType,
    WorkloadIssueManagementStatusType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AccountJiraConfigurationInputTypeDef",
    "AccountJiraConfigurationOutputTypeDef",
    "AdditionalResourcesTypeDef",
    "AnswerSummaryTypeDef",
    "AnswerTypeDef",
    "AssociateLensesInputRequestTypeDef",
    "AssociateProfilesInputRequestTypeDef",
    "BestPracticeTypeDef",
    "CheckDetailTypeDef",
    "CheckSummaryTypeDef",
    "ChoiceAnswerSummaryTypeDef",
    "ChoiceAnswerTypeDef",
    "ChoiceContentTypeDef",
    "ChoiceImprovementPlanTypeDef",
    "ChoiceTypeDef",
    "ChoiceUpdateTypeDef",
    "ConsolidatedReportMetricTypeDef",
    "CreateLensShareInputRequestTypeDef",
    "CreateLensShareOutputTypeDef",
    "CreateLensVersionInputRequestTypeDef",
    "CreateLensVersionOutputTypeDef",
    "CreateMilestoneInputRequestTypeDef",
    "CreateMilestoneOutputTypeDef",
    "CreateProfileInputRequestTypeDef",
    "CreateProfileOutputTypeDef",
    "CreateProfileShareInputRequestTypeDef",
    "CreateProfileShareOutputTypeDef",
    "CreateReviewTemplateInputRequestTypeDef",
    "CreateReviewTemplateOutputTypeDef",
    "CreateTemplateShareInputRequestTypeDef",
    "CreateTemplateShareOutputTypeDef",
    "CreateWorkloadInputRequestTypeDef",
    "CreateWorkloadOutputTypeDef",
    "CreateWorkloadShareInputRequestTypeDef",
    "CreateWorkloadShareOutputTypeDef",
    "DeleteLensInputRequestTypeDef",
    "DeleteLensShareInputRequestTypeDef",
    "DeleteProfileInputRequestTypeDef",
    "DeleteProfileShareInputRequestTypeDef",
    "DeleteReviewTemplateInputRequestTypeDef",
    "DeleteTemplateShareInputRequestTypeDef",
    "DeleteWorkloadInputRequestTypeDef",
    "DeleteWorkloadShareInputRequestTypeDef",
    "DisassociateLensesInputRequestTypeDef",
    "DisassociateProfilesInputRequestTypeDef",
    "EmptyResponseMetadataTypeDef",
    "ExportLensInputRequestTypeDef",
    "ExportLensOutputTypeDef",
    "GetAnswerInputRequestTypeDef",
    "GetAnswerOutputTypeDef",
    "GetConsolidatedReportInputRequestTypeDef",
    "GetConsolidatedReportOutputTypeDef",
    "GetGlobalSettingsOutputTypeDef",
    "GetLensInputRequestTypeDef",
    "GetLensOutputTypeDef",
    "GetLensReviewInputRequestTypeDef",
    "GetLensReviewOutputTypeDef",
    "GetLensReviewReportInputRequestTypeDef",
    "GetLensReviewReportOutputTypeDef",
    "GetLensVersionDifferenceInputRequestTypeDef",
    "GetLensVersionDifferenceOutputTypeDef",
    "GetMilestoneInputRequestTypeDef",
    "GetMilestoneOutputTypeDef",
    "GetProfileInputRequestTypeDef",
    "GetProfileOutputTypeDef",
    "GetProfileTemplateOutputTypeDef",
    "GetReviewTemplateAnswerInputRequestTypeDef",
    "GetReviewTemplateAnswerOutputTypeDef",
    "GetReviewTemplateInputRequestTypeDef",
    "GetReviewTemplateLensReviewInputRequestTypeDef",
    "GetReviewTemplateLensReviewOutputTypeDef",
    "GetReviewTemplateOutputTypeDef",
    "GetWorkloadInputRequestTypeDef",
    "GetWorkloadOutputTypeDef",
    "ImportLensInputRequestTypeDef",
    "ImportLensOutputTypeDef",
    "ImprovementSummaryTypeDef",
    "JiraConfigurationTypeDef",
    "JiraSelectedQuestionConfigurationOutputTypeDef",
    "JiraSelectedQuestionConfigurationTypeDef",
    "LensMetricTypeDef",
    "LensReviewReportTypeDef",
    "LensReviewSummaryTypeDef",
    "LensReviewTypeDef",
    "LensShareSummaryTypeDef",
    "LensSummaryTypeDef",
    "LensTypeDef",
    "LensUpgradeSummaryTypeDef",
    "ListAnswersInputRequestTypeDef",
    "ListAnswersOutputTypeDef",
    "ListCheckDetailsInputRequestTypeDef",
    "ListCheckDetailsOutputTypeDef",
    "ListCheckSummariesInputRequestTypeDef",
    "ListCheckSummariesOutputTypeDef",
    "ListLensReviewImprovementsInputRequestTypeDef",
    "ListLensReviewImprovementsOutputTypeDef",
    "ListLensReviewsInputRequestTypeDef",
    "ListLensReviewsOutputTypeDef",
    "ListLensSharesInputRequestTypeDef",
    "ListLensSharesOutputTypeDef",
    "ListLensesInputRequestTypeDef",
    "ListLensesOutputTypeDef",
    "ListMilestonesInputRequestTypeDef",
    "ListMilestonesOutputTypeDef",
    "ListNotificationsInputRequestTypeDef",
    "ListNotificationsOutputTypeDef",
    "ListProfileNotificationsInputRequestTypeDef",
    "ListProfileNotificationsOutputTypeDef",
    "ListProfileSharesInputRequestTypeDef",
    "ListProfileSharesOutputTypeDef",
    "ListProfilesInputRequestTypeDef",
    "ListProfilesOutputTypeDef",
    "ListReviewTemplateAnswersInputRequestTypeDef",
    "ListReviewTemplateAnswersOutputTypeDef",
    "ListReviewTemplatesInputRequestTypeDef",
    "ListReviewTemplatesOutputTypeDef",
    "ListShareInvitationsInputRequestTypeDef",
    "ListShareInvitationsOutputTypeDef",
    "ListTagsForResourceInputRequestTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "ListTemplateSharesInputRequestTypeDef",
    "ListTemplateSharesOutputTypeDef",
    "ListWorkloadSharesInputRequestTypeDef",
    "ListWorkloadSharesOutputTypeDef",
    "ListWorkloadsInputRequestTypeDef",
    "ListWorkloadsOutputTypeDef",
    "MilestoneSummaryTypeDef",
    "MilestoneTypeDef",
    "NotificationSummaryTypeDef",
    "PillarDifferenceTypeDef",
    "PillarMetricTypeDef",
    "PillarReviewSummaryTypeDef",
    "ProfileChoiceTypeDef",
    "ProfileNotificationSummaryTypeDef",
    "ProfileQuestionTypeDef",
    "ProfileQuestionUpdateTypeDef",
    "ProfileShareSummaryTypeDef",
    "ProfileSummaryTypeDef",
    "ProfileTemplateChoiceTypeDef",
    "ProfileTemplateQuestionTypeDef",
    "ProfileTemplateTypeDef",
    "ProfileTypeDef",
    "QuestionDifferenceTypeDef",
    "QuestionMetricTypeDef",
    "ResponseMetadataTypeDef",
    "ReviewTemplateAnswerSummaryTypeDef",
    "ReviewTemplateAnswerTypeDef",
    "ReviewTemplateLensReviewTypeDef",
    "ReviewTemplatePillarReviewSummaryTypeDef",
    "ReviewTemplateSummaryTypeDef",
    "ReviewTemplateTypeDef",
    "SelectedPillarOutputTypeDef",
    "SelectedPillarTypeDef",
    "SelectedPillarUnionTypeDef",
    "ShareInvitationSummaryTypeDef",
    "ShareInvitationTypeDef",
    "TagResourceInputRequestTypeDef",
    "TemplateShareSummaryTypeDef",
    "UntagResourceInputRequestTypeDef",
    "UpdateAnswerInputRequestTypeDef",
    "UpdateAnswerOutputTypeDef",
    "UpdateGlobalSettingsInputRequestTypeDef",
    "UpdateIntegrationInputRequestTypeDef",
    "UpdateLensReviewInputRequestTypeDef",
    "UpdateLensReviewOutputTypeDef",
    "UpdateProfileInputRequestTypeDef",
    "UpdateProfileOutputTypeDef",
    "UpdateReviewTemplateAnswerInputRequestTypeDef",
    "UpdateReviewTemplateAnswerOutputTypeDef",
    "UpdateReviewTemplateInputRequestTypeDef",
    "UpdateReviewTemplateLensReviewInputRequestTypeDef",
    "UpdateReviewTemplateLensReviewOutputTypeDef",
    "UpdateReviewTemplateOutputTypeDef",
    "UpdateShareInvitationInputRequestTypeDef",
    "UpdateShareInvitationOutputTypeDef",
    "UpdateWorkloadInputRequestTypeDef",
    "UpdateWorkloadOutputTypeDef",
    "UpdateWorkloadShareInputRequestTypeDef",
    "UpdateWorkloadShareOutputTypeDef",
    "UpgradeLensReviewInputRequestTypeDef",
    "UpgradeProfileVersionInputRequestTypeDef",
    "UpgradeReviewTemplateLensReviewInputRequestTypeDef",
    "VersionDifferencesTypeDef",
    "WorkloadDiscoveryConfigOutputTypeDef",
    "WorkloadDiscoveryConfigTypeDef",
    "WorkloadJiraConfigurationInputTypeDef",
    "WorkloadJiraConfigurationOutputTypeDef",
    "WorkloadProfileTypeDef",
    "WorkloadShareSummaryTypeDef",
    "WorkloadShareTypeDef",
    "WorkloadSummaryTypeDef",
    "WorkloadTypeDef",
)


class AccountJiraConfigurationInputTypeDef(TypedDict):
    IssueManagementStatus: NotRequired[AccountJiraIssueManagementStatusType]
    IssueManagementType: NotRequired[IssueManagementTypeType]
    JiraProjectKey: NotRequired[str]
    IntegrationStatus: NotRequired[Literal["NOT_CONFIGURED"]]


class AccountJiraConfigurationOutputTypeDef(TypedDict):
    IntegrationStatus: NotRequired[IntegrationStatusType]
    IssueManagementStatus: NotRequired[AccountJiraIssueManagementStatusType]
    IssueManagementType: NotRequired[IssueManagementTypeType]
    Subdomain: NotRequired[str]
    JiraProjectKey: NotRequired[str]
    StatusMessage: NotRequired[str]


class ChoiceContentTypeDef(TypedDict):
    DisplayText: NotRequired[str]
    Url: NotRequired[str]


class ChoiceAnswerSummaryTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    Status: NotRequired[ChoiceStatusType]
    Reason: NotRequired[ChoiceReasonType]


class JiraConfigurationTypeDef(TypedDict):
    JiraIssueUrl: NotRequired[str]
    LastSyncedTime: NotRequired[datetime]


class ChoiceAnswerTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    Status: NotRequired[ChoiceStatusType]
    Reason: NotRequired[ChoiceReasonType]
    Notes: NotRequired[str]


class AssociateLensesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAliases: Sequence[str]


class AssociateProfilesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    ProfileArns: Sequence[str]


class BestPracticeTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    ChoiceTitle: NotRequired[str]


class CheckDetailTypeDef(TypedDict):
    Id: NotRequired[str]
    Name: NotRequired[str]
    Description: NotRequired[str]
    Provider: NotRequired[Literal["TRUSTED_ADVISOR"]]
    LensArn: NotRequired[str]
    PillarId: NotRequired[str]
    QuestionId: NotRequired[str]
    ChoiceId: NotRequired[str]
    Status: NotRequired[CheckStatusType]
    AccountId: NotRequired[str]
    FlaggedResources: NotRequired[int]
    Reason: NotRequired[CheckFailureReasonType]
    UpdatedAt: NotRequired[datetime]


class CheckSummaryTypeDef(TypedDict):
    Id: NotRequired[str]
    Name: NotRequired[str]
    Provider: NotRequired[Literal["TRUSTED_ADVISOR"]]
    Description: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    LensArn: NotRequired[str]
    PillarId: NotRequired[str]
    QuestionId: NotRequired[str]
    ChoiceId: NotRequired[str]
    Status: NotRequired[CheckStatusType]
    AccountSummary: NotRequired[dict[CheckStatusType, int]]


class ChoiceImprovementPlanTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    DisplayText: NotRequired[str]
    ImprovementPlanUrl: NotRequired[str]


class ChoiceUpdateTypeDef(TypedDict):
    Status: ChoiceStatusType
    Reason: NotRequired[ChoiceReasonType]
    Notes: NotRequired[str]


class CreateLensShareInputRequestTypeDef(TypedDict):
    LensAlias: str
    SharedWith: str
    ClientRequestToken: str


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class CreateLensVersionInputRequestTypeDef(TypedDict):
    LensAlias: str
    LensVersion: str
    ClientRequestToken: str
    IsMajorVersion: NotRequired[bool]


class CreateMilestoneInputRequestTypeDef(TypedDict):
    WorkloadId: str
    MilestoneName: str
    ClientRequestToken: str


class ProfileQuestionUpdateTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    SelectedChoiceIds: NotRequired[Sequence[str]]


class CreateProfileShareInputRequestTypeDef(TypedDict):
    ProfileArn: str
    SharedWith: str
    ClientRequestToken: str


class CreateReviewTemplateInputRequestTypeDef(TypedDict):
    TemplateName: str
    Description: str
    Lenses: Sequence[str]
    ClientRequestToken: str
    Notes: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]


class CreateTemplateShareInputRequestTypeDef(TypedDict):
    TemplateArn: str
    SharedWith: str
    ClientRequestToken: str


class WorkloadDiscoveryConfigTypeDef(TypedDict):
    TrustedAdvisorIntegrationStatus: NotRequired[TrustedAdvisorIntegrationStatusType]
    WorkloadResourceDefinition: NotRequired[Sequence[DefinitionTypeType]]


class WorkloadJiraConfigurationInputTypeDef(TypedDict):
    IssueManagementStatus: NotRequired[WorkloadIssueManagementStatusType]
    IssueManagementType: NotRequired[IssueManagementTypeType]
    JiraProjectKey: NotRequired[str]


class CreateWorkloadShareInputRequestTypeDef(TypedDict):
    WorkloadId: str
    SharedWith: str
    PermissionType: PermissionTypeType
    ClientRequestToken: str


class DeleteLensInputRequestTypeDef(TypedDict):
    LensAlias: str
    ClientRequestToken: str
    LensStatus: LensStatusTypeType


class DeleteLensShareInputRequestTypeDef(TypedDict):
    ShareId: str
    LensAlias: str
    ClientRequestToken: str


class DeleteProfileInputRequestTypeDef(TypedDict):
    ProfileArn: str
    ClientRequestToken: str


class DeleteProfileShareInputRequestTypeDef(TypedDict):
    ShareId: str
    ProfileArn: str
    ClientRequestToken: str


class DeleteReviewTemplateInputRequestTypeDef(TypedDict):
    TemplateArn: str
    ClientRequestToken: str


class DeleteTemplateShareInputRequestTypeDef(TypedDict):
    ShareId: str
    TemplateArn: str
    ClientRequestToken: str


class DeleteWorkloadInputRequestTypeDef(TypedDict):
    WorkloadId: str
    ClientRequestToken: str


class DeleteWorkloadShareInputRequestTypeDef(TypedDict):
    ShareId: str
    WorkloadId: str
    ClientRequestToken: str


class DisassociateLensesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAliases: Sequence[str]


class DisassociateProfilesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    ProfileArns: Sequence[str]


class ExportLensInputRequestTypeDef(TypedDict):
    LensAlias: str
    LensVersion: NotRequired[str]


class GetAnswerInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    QuestionId: str
    MilestoneNumber: NotRequired[int]


class GetConsolidatedReportInputRequestTypeDef(TypedDict):
    Format: ReportFormatType
    IncludeSharedResources: NotRequired[bool]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class GetLensInputRequestTypeDef(TypedDict):
    LensAlias: str
    LensVersion: NotRequired[str]


class LensTypeDef(TypedDict):
    LensArn: NotRequired[str]
    LensVersion: NotRequired[str]
    Name: NotRequired[str]
    Description: NotRequired[str]
    Owner: NotRequired[str]
    ShareInvitationId: NotRequired[str]
    Tags: NotRequired[dict[str, str]]


class GetLensReviewInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    MilestoneNumber: NotRequired[int]


class GetLensReviewReportInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    MilestoneNumber: NotRequired[int]


class LensReviewReportTypeDef(TypedDict):
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    Base64String: NotRequired[str]


class GetLensVersionDifferenceInputRequestTypeDef(TypedDict):
    LensAlias: str
    BaseLensVersion: NotRequired[str]
    TargetLensVersion: NotRequired[str]


class GetMilestoneInputRequestTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int


class GetProfileInputRequestTypeDef(TypedDict):
    ProfileArn: str
    ProfileVersion: NotRequired[str]


class GetReviewTemplateAnswerInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    QuestionId: str


class GetReviewTemplateInputRequestTypeDef(TypedDict):
    TemplateArn: str


class GetReviewTemplateLensReviewInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str


class ReviewTemplateTypeDef(TypedDict):
    Description: NotRequired[str]
    Lenses: NotRequired[list[str]]
    Notes: NotRequired[str]
    QuestionCounts: NotRequired[dict[QuestionType, int]]
    Owner: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    TemplateArn: NotRequired[str]
    TemplateName: NotRequired[str]
    Tags: NotRequired[dict[str, str]]
    UpdateStatus: NotRequired[ReviewTemplateUpdateStatusType]
    ShareInvitationId: NotRequired[str]


class GetWorkloadInputRequestTypeDef(TypedDict):
    WorkloadId: str


class ImportLensInputRequestTypeDef(TypedDict):
    JSONString: str
    ClientRequestToken: str
    LensAlias: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]


class SelectedPillarOutputTypeDef(TypedDict):
    PillarId: NotRequired[str]
    SelectedQuestionIds: NotRequired[list[str]]


class WorkloadProfileTypeDef(TypedDict):
    ProfileArn: NotRequired[str]
    ProfileVersion: NotRequired[str]


class PillarReviewSummaryTypeDef(TypedDict):
    PillarId: NotRequired[str]
    PillarName: NotRequired[str]
    Notes: NotRequired[str]
    RiskCounts: NotRequired[dict[RiskType, int]]
    PrioritizedRiskCounts: NotRequired[dict[RiskType, int]]


class LensShareSummaryTypeDef(TypedDict):
    ShareId: NotRequired[str]
    SharedWith: NotRequired[str]
    Status: NotRequired[ShareStatusType]
    StatusMessage: NotRequired[str]


class LensSummaryTypeDef(TypedDict):
    LensArn: NotRequired[str]
    LensAlias: NotRequired[str]
    LensName: NotRequired[str]
    LensType: NotRequired[LensTypeType]
    Description: NotRequired[str]
    CreatedAt: NotRequired[datetime]
    UpdatedAt: NotRequired[datetime]
    LensVersion: NotRequired[str]
    Owner: NotRequired[str]
    LensStatus: NotRequired[LensStatusType]


class LensUpgradeSummaryTypeDef(TypedDict):
    WorkloadId: NotRequired[str]
    WorkloadName: NotRequired[str]
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    CurrentLensVersion: NotRequired[str]
    LatestLensVersion: NotRequired[str]
    ResourceArn: NotRequired[str]
    ResourceName: NotRequired[str]


class ListAnswersInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    PillarId: NotRequired[str]
    MilestoneNumber: NotRequired[int]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    QuestionPriority: NotRequired[QuestionPriorityType]


class ListCheckDetailsInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensArn: str
    PillarId: str
    QuestionId: str
    ChoiceId: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListCheckSummariesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensArn: str
    PillarId: str
    QuestionId: str
    ChoiceId: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListLensReviewImprovementsInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    PillarId: NotRequired[str]
    MilestoneNumber: NotRequired[int]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    QuestionPriority: NotRequired[QuestionPriorityType]


class ListLensReviewsInputRequestTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: NotRequired[int]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListLensSharesInputRequestTypeDef(TypedDict):
    LensAlias: str
    SharedWithPrefix: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    Status: NotRequired[ShareStatusType]


class ListLensesInputRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    LensType: NotRequired[LensTypeType]
    LensStatus: NotRequired[LensStatusTypeType]
    LensName: NotRequired[str]


class ListMilestonesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListNotificationsInputRequestTypeDef(TypedDict):
    WorkloadId: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    ResourceArn: NotRequired[str]


class ListProfileNotificationsInputRequestTypeDef(TypedDict):
    WorkloadId: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


ProfileNotificationSummaryTypeDef = TypedDict(
    "ProfileNotificationSummaryTypeDef",
    {
        "CurrentProfileVersion": NotRequired[str],
        "LatestProfileVersion": NotRequired[str],
        "Type": NotRequired[ProfileNotificationTypeType],
        "ProfileArn": NotRequired[str],
        "ProfileName": NotRequired[str],
        "WorkloadId": NotRequired[str],
        "WorkloadName": NotRequired[str],
    },
)


class ListProfileSharesInputRequestTypeDef(TypedDict):
    ProfileArn: str
    SharedWithPrefix: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    Status: NotRequired[ShareStatusType]


class ProfileShareSummaryTypeDef(TypedDict):
    ShareId: NotRequired[str]
    SharedWith: NotRequired[str]
    Status: NotRequired[ShareStatusType]
    StatusMessage: NotRequired[str]


class ListProfilesInputRequestTypeDef(TypedDict):
    ProfileNamePrefix: NotRequired[str]
    ProfileOwnerType: NotRequired[ProfileOwnerTypeType]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ProfileSummaryTypeDef(TypedDict):
    ProfileArn: NotRequired[str]
    ProfileVersion: NotRequired[str]
    ProfileName: NotRequired[str]
    ProfileDescription: NotRequired[str]
    Owner: NotRequired[str]
    CreatedAt: NotRequired[datetime]
    UpdatedAt: NotRequired[datetime]


class ListReviewTemplateAnswersInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    PillarId: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListReviewTemplatesInputRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ReviewTemplateSummaryTypeDef(TypedDict):
    Description: NotRequired[str]
    Lenses: NotRequired[list[str]]
    Owner: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    TemplateArn: NotRequired[str]
    TemplateName: NotRequired[str]
    UpdateStatus: NotRequired[ReviewTemplateUpdateStatusType]


class ListShareInvitationsInputRequestTypeDef(TypedDict):
    WorkloadNamePrefix: NotRequired[str]
    LensNamePrefix: NotRequired[str]
    ShareResourceType: NotRequired[ShareResourceTypeType]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    ProfileNamePrefix: NotRequired[str]
    TemplateNamePrefix: NotRequired[str]


class ShareInvitationSummaryTypeDef(TypedDict):
    ShareInvitationId: NotRequired[str]
    SharedBy: NotRequired[str]
    SharedWith: NotRequired[str]
    PermissionType: NotRequired[PermissionTypeType]
    ShareResourceType: NotRequired[ShareResourceTypeType]
    WorkloadName: NotRequired[str]
    WorkloadId: NotRequired[str]
    LensName: NotRequired[str]
    LensArn: NotRequired[str]
    ProfileName: NotRequired[str]
    ProfileArn: NotRequired[str]
    TemplateName: NotRequired[str]
    TemplateArn: NotRequired[str]


class ListTagsForResourceInputRequestTypeDef(TypedDict):
    WorkloadArn: str


class ListTemplateSharesInputRequestTypeDef(TypedDict):
    TemplateArn: str
    SharedWithPrefix: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    Status: NotRequired[ShareStatusType]


class TemplateShareSummaryTypeDef(TypedDict):
    ShareId: NotRequired[str]
    SharedWith: NotRequired[str]
    Status: NotRequired[ShareStatusType]
    StatusMessage: NotRequired[str]


class ListWorkloadSharesInputRequestTypeDef(TypedDict):
    WorkloadId: str
    SharedWithPrefix: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]
    Status: NotRequired[ShareStatusType]


class WorkloadShareSummaryTypeDef(TypedDict):
    ShareId: NotRequired[str]
    SharedWith: NotRequired[str]
    PermissionType: NotRequired[PermissionTypeType]
    Status: NotRequired[ShareStatusType]
    StatusMessage: NotRequired[str]


class ListWorkloadsInputRequestTypeDef(TypedDict):
    WorkloadNamePrefix: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class QuestionDifferenceTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    DifferenceStatus: NotRequired[DifferenceStatusType]


class ProfileChoiceTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    ChoiceTitle: NotRequired[str]
    ChoiceDescription: NotRequired[str]


class ProfileTemplateChoiceTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    ChoiceTitle: NotRequired[str]
    ChoiceDescription: NotRequired[str]


class ReviewTemplatePillarReviewSummaryTypeDef(TypedDict):
    PillarId: NotRequired[str]
    PillarName: NotRequired[str]
    Notes: NotRequired[str]
    QuestionCounts: NotRequired[dict[QuestionType, int]]


class SelectedPillarTypeDef(TypedDict):
    PillarId: NotRequired[str]
    SelectedQuestionIds: NotRequired[Sequence[str]]


class ShareInvitationTypeDef(TypedDict):
    ShareInvitationId: NotRequired[str]
    ShareResourceType: NotRequired[ShareResourceTypeType]
    WorkloadId: NotRequired[str]
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    ProfileArn: NotRequired[str]
    TemplateArn: NotRequired[str]


class TagResourceInputRequestTypeDef(TypedDict):
    WorkloadArn: str
    Tags: Mapping[str, str]


class UntagResourceInputRequestTypeDef(TypedDict):
    WorkloadArn: str
    TagKeys: Sequence[str]


class UpdateIntegrationInputRequestTypeDef(TypedDict):
    WorkloadId: str
    ClientRequestToken: str
    IntegratingService: Literal["JIRA"]


class UpdateReviewTemplateInputRequestTypeDef(TypedDict):
    TemplateArn: str
    TemplateName: NotRequired[str]
    Description: NotRequired[str]
    Notes: NotRequired[str]
    LensesToAssociate: NotRequired[Sequence[str]]
    LensesToDisassociate: NotRequired[Sequence[str]]


class UpdateReviewTemplateLensReviewInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    LensNotes: NotRequired[str]
    PillarNotes: NotRequired[Mapping[str, str]]


class UpdateShareInvitationInputRequestTypeDef(TypedDict):
    ShareInvitationId: str
    ShareInvitationAction: ShareInvitationActionType


class UpdateWorkloadShareInputRequestTypeDef(TypedDict):
    ShareId: str
    WorkloadId: str
    PermissionType: PermissionTypeType


class WorkloadShareTypeDef(TypedDict):
    ShareId: NotRequired[str]
    SharedBy: NotRequired[str]
    SharedWith: NotRequired[str]
    PermissionType: NotRequired[PermissionTypeType]
    Status: NotRequired[ShareStatusType]
    WorkloadName: NotRequired[str]
    WorkloadId: NotRequired[str]


class UpgradeLensReviewInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    MilestoneName: str
    ClientRequestToken: NotRequired[str]


class UpgradeProfileVersionInputRequestTypeDef(TypedDict):
    WorkloadId: str
    ProfileArn: str
    MilestoneName: NotRequired[str]
    ClientRequestToken: NotRequired[str]


class UpgradeReviewTemplateLensReviewInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    ClientRequestToken: NotRequired[str]


class WorkloadDiscoveryConfigOutputTypeDef(TypedDict):
    TrustedAdvisorIntegrationStatus: NotRequired[TrustedAdvisorIntegrationStatusType]
    WorkloadResourceDefinition: NotRequired[list[DefinitionTypeType]]


class WorkloadJiraConfigurationOutputTypeDef(TypedDict):
    IssueManagementStatus: NotRequired[WorkloadIssueManagementStatusType]
    IssueManagementType: NotRequired[IssueManagementTypeType]
    JiraProjectKey: NotRequired[str]
    StatusMessage: NotRequired[str]


class UpdateGlobalSettingsInputRequestTypeDef(TypedDict):
    OrganizationSharingStatus: NotRequired[OrganizationSharingStatusType]
    DiscoveryIntegrationStatus: NotRequired[DiscoveryIntegrationStatusType]
    JiraConfiguration: NotRequired[AccountJiraConfigurationInputTypeDef]


AdditionalResourcesTypeDef = TypedDict(
    "AdditionalResourcesTypeDef",
    {
        "Type": NotRequired[AdditionalResourceTypeType],
        "Content": NotRequired[list[ChoiceContentTypeDef]],
    },
)


class QuestionMetricTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    Risk: NotRequired[RiskType]
    BestPractices: NotRequired[list[BestPracticeTypeDef]]


class ImprovementSummaryTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    PillarId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    Risk: NotRequired[RiskType]
    ImprovementPlanUrl: NotRequired[str]
    ImprovementPlans: NotRequired[list[ChoiceImprovementPlanTypeDef]]
    JiraConfiguration: NotRequired[JiraConfigurationTypeDef]


class UpdateAnswerInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    QuestionId: str
    SelectedChoices: NotRequired[Sequence[str]]
    ChoiceUpdates: NotRequired[Mapping[str, ChoiceUpdateTypeDef]]
    Notes: NotRequired[str]
    IsApplicable: NotRequired[bool]
    Reason: NotRequired[AnswerReasonType]


class UpdateReviewTemplateAnswerInputRequestTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    QuestionId: str
    SelectedChoices: NotRequired[Sequence[str]]
    ChoiceUpdates: NotRequired[Mapping[str, ChoiceUpdateTypeDef]]
    Notes: NotRequired[str]
    IsApplicable: NotRequired[bool]
    Reason: NotRequired[AnswerReasonType]


class CreateLensShareOutputTypeDef(TypedDict):
    ShareId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateLensVersionOutputTypeDef(TypedDict):
    LensArn: str
    LensVersion: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateMilestoneOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    ResponseMetadata: ResponseMetadataTypeDef


class CreateProfileOutputTypeDef(TypedDict):
    ProfileArn: str
    ProfileVersion: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateProfileShareOutputTypeDef(TypedDict):
    ShareId: str
    ProfileArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateReviewTemplateOutputTypeDef(TypedDict):
    TemplateArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateTemplateShareOutputTypeDef(TypedDict):
    TemplateArn: str
    ShareId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateWorkloadOutputTypeDef(TypedDict):
    WorkloadId: str
    WorkloadArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateWorkloadShareOutputTypeDef(TypedDict):
    WorkloadId: str
    ShareId: str
    ResponseMetadata: ResponseMetadataTypeDef


class EmptyResponseMetadataTypeDef(TypedDict):
    ResponseMetadata: ResponseMetadataTypeDef


class ExportLensOutputTypeDef(TypedDict):
    LensJSON: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetGlobalSettingsOutputTypeDef(TypedDict):
    OrganizationSharingStatus: OrganizationSharingStatusType
    DiscoveryIntegrationStatus: DiscoveryIntegrationStatusType
    JiraConfiguration: AccountJiraConfigurationOutputTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ImportLensOutputTypeDef(TypedDict):
    LensArn: str
    Status: ImportLensStatusType
    ResponseMetadata: ResponseMetadataTypeDef


class ListCheckDetailsOutputTypeDef(TypedDict):
    CheckDetails: list[CheckDetailTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListCheckSummariesOutputTypeDef(TypedDict):
    CheckSummaries: list[CheckSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTagsForResourceOutputTypeDef(TypedDict):
    Tags: dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef


class CreateProfileInputRequestTypeDef(TypedDict):
    ProfileName: str
    ProfileDescription: str
    ProfileQuestions: Sequence[ProfileQuestionUpdateTypeDef]
    ClientRequestToken: str
    Tags: NotRequired[Mapping[str, str]]


class UpdateProfileInputRequestTypeDef(TypedDict):
    ProfileArn: str
    ProfileDescription: NotRequired[str]
    ProfileQuestions: NotRequired[Sequence[ProfileQuestionUpdateTypeDef]]


class CreateWorkloadInputRequestTypeDef(TypedDict):
    WorkloadName: str
    Description: str
    Environment: WorkloadEnvironmentType
    Lenses: Sequence[str]
    ClientRequestToken: str
    AccountIds: NotRequired[Sequence[str]]
    AwsRegions: NotRequired[Sequence[str]]
    NonAwsRegions: NotRequired[Sequence[str]]
    PillarPriorities: NotRequired[Sequence[str]]
    ArchitecturalDesign: NotRequired[str]
    ReviewOwner: NotRequired[str]
    IndustryType: NotRequired[str]
    Industry: NotRequired[str]
    Notes: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]
    DiscoveryConfig: NotRequired[WorkloadDiscoveryConfigTypeDef]
    Applications: NotRequired[Sequence[str]]
    ProfileArns: NotRequired[Sequence[str]]
    ReviewTemplateArns: NotRequired[Sequence[str]]
    JiraConfiguration: NotRequired[WorkloadJiraConfigurationInputTypeDef]


class UpdateWorkloadInputRequestTypeDef(TypedDict):
    WorkloadId: str
    WorkloadName: NotRequired[str]
    Description: NotRequired[str]
    Environment: NotRequired[WorkloadEnvironmentType]
    AccountIds: NotRequired[Sequence[str]]
    AwsRegions: NotRequired[Sequence[str]]
    NonAwsRegions: NotRequired[Sequence[str]]
    PillarPriorities: NotRequired[Sequence[str]]
    ArchitecturalDesign: NotRequired[str]
    ReviewOwner: NotRequired[str]
    IsReviewOwnerUpdateAcknowledged: NotRequired[bool]
    IndustryType: NotRequired[str]
    Industry: NotRequired[str]
    Notes: NotRequired[str]
    ImprovementStatus: NotRequired[WorkloadImprovementStatusType]
    DiscoveryConfig: NotRequired[WorkloadDiscoveryConfigTypeDef]
    Applications: NotRequired[Sequence[str]]
    JiraConfiguration: NotRequired[WorkloadJiraConfigurationInputTypeDef]


class GetLensOutputTypeDef(TypedDict):
    Lens: LensTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetLensReviewReportOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensReviewReport: LensReviewReportTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetReviewTemplateOutputTypeDef(TypedDict):
    ReviewTemplate: ReviewTemplateTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateReviewTemplateOutputTypeDef(TypedDict):
    ReviewTemplate: ReviewTemplateTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class JiraSelectedQuestionConfigurationOutputTypeDef(TypedDict):
    SelectedPillars: NotRequired[list[SelectedPillarOutputTypeDef]]


class LensReviewSummaryTypeDef(TypedDict):
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    LensVersion: NotRequired[str]
    LensName: NotRequired[str]
    LensStatus: NotRequired[LensStatusType]
    UpdatedAt: NotRequired[datetime]
    RiskCounts: NotRequired[dict[RiskType, int]]
    Profiles: NotRequired[list[WorkloadProfileTypeDef]]
    PrioritizedRiskCounts: NotRequired[dict[RiskType, int]]


class WorkloadSummaryTypeDef(TypedDict):
    WorkloadId: NotRequired[str]
    WorkloadArn: NotRequired[str]
    WorkloadName: NotRequired[str]
    Owner: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    Lenses: NotRequired[list[str]]
    RiskCounts: NotRequired[dict[RiskType, int]]
    ImprovementStatus: NotRequired[WorkloadImprovementStatusType]
    Profiles: NotRequired[list[WorkloadProfileTypeDef]]
    PrioritizedRiskCounts: NotRequired[dict[RiskType, int]]


class ListLensSharesOutputTypeDef(TypedDict):
    LensShareSummaries: list[LensShareSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListLensesOutputTypeDef(TypedDict):
    LensSummaries: list[LensSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


NotificationSummaryTypeDef = TypedDict(
    "NotificationSummaryTypeDef",
    {
        "Type": NotRequired[NotificationTypeType],
        "LensUpgradeSummary": NotRequired[LensUpgradeSummaryTypeDef],
    },
)


class ListProfileNotificationsOutputTypeDef(TypedDict):
    NotificationSummaries: list[ProfileNotificationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListProfileSharesOutputTypeDef(TypedDict):
    ProfileShareSummaries: list[ProfileShareSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListProfilesOutputTypeDef(TypedDict):
    ProfileSummaries: list[ProfileSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListReviewTemplatesOutputTypeDef(TypedDict):
    ReviewTemplates: list[ReviewTemplateSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListShareInvitationsOutputTypeDef(TypedDict):
    ShareInvitationSummaries: list[ShareInvitationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTemplateSharesOutputTypeDef(TypedDict):
    TemplateArn: str
    TemplateShareSummaries: list[TemplateShareSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListWorkloadSharesOutputTypeDef(TypedDict):
    WorkloadId: str
    WorkloadShareSummaries: list[WorkloadShareSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class PillarDifferenceTypeDef(TypedDict):
    PillarId: NotRequired[str]
    PillarName: NotRequired[str]
    DifferenceStatus: NotRequired[DifferenceStatusType]
    QuestionDifferences: NotRequired[list[QuestionDifferenceTypeDef]]


class ProfileQuestionTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    QuestionDescription: NotRequired[str]
    QuestionChoices: NotRequired[list[ProfileChoiceTypeDef]]
    SelectedChoiceIds: NotRequired[list[str]]
    MinSelectedChoices: NotRequired[int]
    MaxSelectedChoices: NotRequired[int]


class ProfileTemplateQuestionTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    QuestionDescription: NotRequired[str]
    QuestionChoices: NotRequired[list[ProfileTemplateChoiceTypeDef]]
    MinSelectedChoices: NotRequired[int]
    MaxSelectedChoices: NotRequired[int]


class ReviewTemplateLensReviewTypeDef(TypedDict):
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    LensVersion: NotRequired[str]
    LensName: NotRequired[str]
    LensStatus: NotRequired[LensStatusType]
    PillarReviewSummaries: NotRequired[list[ReviewTemplatePillarReviewSummaryTypeDef]]
    UpdatedAt: NotRequired[datetime]
    Notes: NotRequired[str]
    QuestionCounts: NotRequired[dict[QuestionType, int]]
    NextToken: NotRequired[str]


SelectedPillarUnionTypeDef = Union[SelectedPillarTypeDef, SelectedPillarOutputTypeDef]


class UpdateShareInvitationOutputTypeDef(TypedDict):
    ShareInvitation: ShareInvitationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateWorkloadShareOutputTypeDef(TypedDict):
    WorkloadId: str
    WorkloadShare: WorkloadShareTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class WorkloadTypeDef(TypedDict):
    WorkloadId: NotRequired[str]
    WorkloadArn: NotRequired[str]
    WorkloadName: NotRequired[str]
    Description: NotRequired[str]
    Environment: NotRequired[WorkloadEnvironmentType]
    UpdatedAt: NotRequired[datetime]
    AccountIds: NotRequired[list[str]]
    AwsRegions: NotRequired[list[str]]
    NonAwsRegions: NotRequired[list[str]]
    ArchitecturalDesign: NotRequired[str]
    ReviewOwner: NotRequired[str]
    ReviewRestrictionDate: NotRequired[datetime]
    IsReviewOwnerUpdateAcknowledged: NotRequired[bool]
    IndustryType: NotRequired[str]
    Industry: NotRequired[str]
    Notes: NotRequired[str]
    ImprovementStatus: NotRequired[WorkloadImprovementStatusType]
    RiskCounts: NotRequired[dict[RiskType, int]]
    PillarPriorities: NotRequired[list[str]]
    Lenses: NotRequired[list[str]]
    Owner: NotRequired[str]
    ShareInvitationId: NotRequired[str]
    Tags: NotRequired[dict[str, str]]
    DiscoveryConfig: NotRequired[WorkloadDiscoveryConfigOutputTypeDef]
    Applications: NotRequired[list[str]]
    Profiles: NotRequired[list[WorkloadProfileTypeDef]]
    PrioritizedRiskCounts: NotRequired[dict[RiskType, int]]
    JiraConfiguration: NotRequired[WorkloadJiraConfigurationOutputTypeDef]


class ChoiceTypeDef(TypedDict):
    ChoiceId: NotRequired[str]
    Title: NotRequired[str]
    Description: NotRequired[str]
    HelpfulResource: NotRequired[ChoiceContentTypeDef]
    ImprovementPlan: NotRequired[ChoiceContentTypeDef]
    AdditionalResources: NotRequired[list[AdditionalResourcesTypeDef]]


class PillarMetricTypeDef(TypedDict):
    PillarId: NotRequired[str]
    RiskCounts: NotRequired[dict[RiskType, int]]
    Questions: NotRequired[list[QuestionMetricTypeDef]]


class ListLensReviewImprovementsOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensAlias: str
    LensArn: str
    ImprovementSummaries: list[ImprovementSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class LensReviewTypeDef(TypedDict):
    LensAlias: NotRequired[str]
    LensArn: NotRequired[str]
    LensVersion: NotRequired[str]
    LensName: NotRequired[str]
    LensStatus: NotRequired[LensStatusType]
    PillarReviewSummaries: NotRequired[list[PillarReviewSummaryTypeDef]]
    JiraConfiguration: NotRequired[JiraSelectedQuestionConfigurationOutputTypeDef]
    UpdatedAt: NotRequired[datetime]
    Notes: NotRequired[str]
    RiskCounts: NotRequired[dict[RiskType, int]]
    NextToken: NotRequired[str]
    Profiles: NotRequired[list[WorkloadProfileTypeDef]]
    PrioritizedRiskCounts: NotRequired[dict[RiskType, int]]


class ListLensReviewsOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensReviewSummaries: list[LensReviewSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListWorkloadsOutputTypeDef(TypedDict):
    WorkloadSummaries: list[WorkloadSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class MilestoneSummaryTypeDef(TypedDict):
    MilestoneNumber: NotRequired[int]
    MilestoneName: NotRequired[str]
    RecordedAt: NotRequired[datetime]
    WorkloadSummary: NotRequired[WorkloadSummaryTypeDef]


class ListNotificationsOutputTypeDef(TypedDict):
    NotificationSummaries: list[NotificationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class VersionDifferencesTypeDef(TypedDict):
    PillarDifferences: NotRequired[list[PillarDifferenceTypeDef]]


class ProfileTypeDef(TypedDict):
    ProfileArn: NotRequired[str]
    ProfileVersion: NotRequired[str]
    ProfileName: NotRequired[str]
    ProfileDescription: NotRequired[str]
    ProfileQuestions: NotRequired[list[ProfileQuestionTypeDef]]
    Owner: NotRequired[str]
    CreatedAt: NotRequired[datetime]
    UpdatedAt: NotRequired[datetime]
    ShareInvitationId: NotRequired[str]
    Tags: NotRequired[dict[str, str]]


class ProfileTemplateTypeDef(TypedDict):
    TemplateName: NotRequired[str]
    TemplateQuestions: NotRequired[list[ProfileTemplateQuestionTypeDef]]
    CreatedAt: NotRequired[datetime]
    UpdatedAt: NotRequired[datetime]


class GetReviewTemplateLensReviewOutputTypeDef(TypedDict):
    TemplateArn: str
    LensReview: ReviewTemplateLensReviewTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateReviewTemplateLensReviewOutputTypeDef(TypedDict):
    TemplateArn: str
    LensReview: ReviewTemplateLensReviewTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class JiraSelectedQuestionConfigurationTypeDef(TypedDict):
    SelectedPillars: NotRequired[Sequence[SelectedPillarUnionTypeDef]]


class GetWorkloadOutputTypeDef(TypedDict):
    Workload: WorkloadTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class MilestoneTypeDef(TypedDict):
    MilestoneNumber: NotRequired[int]
    MilestoneName: NotRequired[str]
    RecordedAt: NotRequired[datetime]
    Workload: NotRequired[WorkloadTypeDef]


class UpdateWorkloadOutputTypeDef(TypedDict):
    Workload: WorkloadTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


AnswerSummaryTypeDef = TypedDict(
    "AnswerSummaryTypeDef",
    {
        "QuestionId": NotRequired[str],
        "PillarId": NotRequired[str],
        "QuestionTitle": NotRequired[str],
        "Choices": NotRequired[list[ChoiceTypeDef]],
        "SelectedChoices": NotRequired[list[str]],
        "ChoiceAnswerSummaries": NotRequired[list[ChoiceAnswerSummaryTypeDef]],
        "IsApplicable": NotRequired[bool],
        "Risk": NotRequired[RiskType],
        "Reason": NotRequired[AnswerReasonType],
        "QuestionType": NotRequired[QuestionTypeType],
        "JiraConfiguration": NotRequired[JiraConfigurationTypeDef],
    },
)


class AnswerTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    PillarId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    QuestionDescription: NotRequired[str]
    ImprovementPlanUrl: NotRequired[str]
    HelpfulResourceUrl: NotRequired[str]
    HelpfulResourceDisplayText: NotRequired[str]
    Choices: NotRequired[list[ChoiceTypeDef]]
    SelectedChoices: NotRequired[list[str]]
    ChoiceAnswers: NotRequired[list[ChoiceAnswerTypeDef]]
    IsApplicable: NotRequired[bool]
    Risk: NotRequired[RiskType]
    Notes: NotRequired[str]
    Reason: NotRequired[AnswerReasonType]
    JiraConfiguration: NotRequired[JiraConfigurationTypeDef]


ReviewTemplateAnswerSummaryTypeDef = TypedDict(
    "ReviewTemplateAnswerSummaryTypeDef",
    {
        "QuestionId": NotRequired[str],
        "PillarId": NotRequired[str],
        "QuestionTitle": NotRequired[str],
        "Choices": NotRequired[list[ChoiceTypeDef]],
        "SelectedChoices": NotRequired[list[str]],
        "ChoiceAnswerSummaries": NotRequired[list[ChoiceAnswerSummaryTypeDef]],
        "IsApplicable": NotRequired[bool],
        "AnswerStatus": NotRequired[ReviewTemplateAnswerStatusType],
        "Reason": NotRequired[AnswerReasonType],
        "QuestionType": NotRequired[QuestionTypeType],
    },
)


class ReviewTemplateAnswerTypeDef(TypedDict):
    QuestionId: NotRequired[str]
    PillarId: NotRequired[str]
    QuestionTitle: NotRequired[str]
    QuestionDescription: NotRequired[str]
    ImprovementPlanUrl: NotRequired[str]
    HelpfulResourceUrl: NotRequired[str]
    HelpfulResourceDisplayText: NotRequired[str]
    Choices: NotRequired[list[ChoiceTypeDef]]
    SelectedChoices: NotRequired[list[str]]
    ChoiceAnswers: NotRequired[list[ChoiceAnswerTypeDef]]
    IsApplicable: NotRequired[bool]
    AnswerStatus: NotRequired[ReviewTemplateAnswerStatusType]
    Notes: NotRequired[str]
    Reason: NotRequired[AnswerReasonType]


class LensMetricTypeDef(TypedDict):
    LensArn: NotRequired[str]
    Pillars: NotRequired[list[PillarMetricTypeDef]]
    RiskCounts: NotRequired[dict[RiskType, int]]


class GetLensReviewOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensReview: LensReviewTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateLensReviewOutputTypeDef(TypedDict):
    WorkloadId: str
    LensReview: LensReviewTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListMilestonesOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneSummaries: list[MilestoneSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetLensVersionDifferenceOutputTypeDef(TypedDict):
    LensAlias: str
    LensArn: str
    BaseLensVersion: str
    TargetLensVersion: str
    LatestLensVersion: str
    VersionDifferences: VersionDifferencesTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetProfileOutputTypeDef(TypedDict):
    Profile: ProfileTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateProfileOutputTypeDef(TypedDict):
    Profile: ProfileTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetProfileTemplateOutputTypeDef(TypedDict):
    ProfileTemplate: ProfileTemplateTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateLensReviewInputRequestTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    LensNotes: NotRequired[str]
    PillarNotes: NotRequired[Mapping[str, str]]
    JiraConfiguration: NotRequired[JiraSelectedQuestionConfigurationTypeDef]


class GetMilestoneOutputTypeDef(TypedDict):
    WorkloadId: str
    Milestone: MilestoneTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListAnswersOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensAlias: str
    LensArn: str
    AnswerSummaries: list[AnswerSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetAnswerOutputTypeDef(TypedDict):
    WorkloadId: str
    MilestoneNumber: int
    LensAlias: str
    LensArn: str
    Answer: AnswerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateAnswerOutputTypeDef(TypedDict):
    WorkloadId: str
    LensAlias: str
    LensArn: str
    Answer: AnswerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListReviewTemplateAnswersOutputTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    AnswerSummaries: list[ReviewTemplateAnswerSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetReviewTemplateAnswerOutputTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    Answer: ReviewTemplateAnswerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateReviewTemplateAnswerOutputTypeDef(TypedDict):
    TemplateArn: str
    LensAlias: str
    Answer: ReviewTemplateAnswerTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ConsolidatedReportMetricTypeDef(TypedDict):
    MetricType: NotRequired[Literal["WORKLOAD"]]
    RiskCounts: NotRequired[dict[RiskType, int]]
    WorkloadId: NotRequired[str]
    WorkloadName: NotRequired[str]
    WorkloadArn: NotRequired[str]
    UpdatedAt: NotRequired[datetime]
    Lenses: NotRequired[list[LensMetricTypeDef]]
    LensesAppliedCount: NotRequired[int]


class GetConsolidatedReportOutputTypeDef(TypedDict):
    Metrics: list[ConsolidatedReportMetricTypeDef]
    Base64String: str
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]
